==> centercontrol-service-2.0.4-zcc-20220211.084806-1-sources.jar: com/bizvane/centercontrolservice/models/vo/SysBrandConfigVo.java <==
package com.bizvane.centercontrolservice.models.vo;

/**
 * @author pc4
 */
public class SysBrandConfigVo {
    /**
     * 品牌成长值开关
     */
    private Boolean growthSwitch;

    /**
     * 成长值功能启用开关
     */
    private Boolean enableGrowthSwitch;

    /**
     * 品牌组织短信开关
     */
    private Boolean organizationSms;

    /**
     * 品牌组织短信功能启用开关
     */
    private Boolean enableOrganizationSms;


    /**
     * 微信解绑功能开关 0关 1开
     * @return
     */
    private Boolean wxUnbindSwitch;

    /**
     * 会员注销功能开关 0关 1开
     */
    private Boolean mbrLogoutSwitch;

    private Boolean wxElectMembershipCardSwitch;
    private Boolean alipayElectMembershipCardSwitch;

    /**
     * 手动执行自动标签数,默认 5
     * @return
     */
    private Integer manualAutuLabelCount;
    /**
     * 每天执行自动标签数,默认 5
     * @return
     */
    private Integer dailyAutuLabelCount;

    /**
     * 导购助手启用最大店铺数状态 0-不限制 1-限制
     * @return
     */
    private Integer maxStoreType;
    /**
     * 导购助手可启用的最大店铺数 数量0不限制
     * @return
     */
    private Integer maxStoreNum;


    /**
     * 区域通是否开启账号数量限制 0-不开启 1-开启
     */
    private Integer maxAreaType;

    /**
     * 区域通限制账号数量限
     */
    private Integer maxAreaNum;

    /**
     * 会员冻结功能开关 0关 1开
     */
    private Boolean mbrFrozenSwitch;

    public Boolean getMbrFrozenSwitch() {
        return mbrFrozenSwitch;
    }

    public void setMbrFrozenSwitch(Boolean mbrFrozenSwitch) {
        this.mbrFrozenSwitch = mbrFrozenSwitch;
    }

    /**
     * 官方标签同步企微开关0关1开
     */
    private Integer wxqyLabelSyncSwitch;

    public Integer getWxqyLabelSyncSwitch() {
        return wxqyLabelSyncSwitch;
    }

    public void setWxqyLabelSyncSwitch(Integer wxqyLabelSyncSwitch) {
        this.wxqyLabelSyncSwitch = wxqyLabelSyncSwitch;
    }

    public Boolean getGrowthSwitch() {
        return growthSwitch;
    }

    public void setGrowthSwitch(Boolean growthSwitch) {
        this.growthSwitch = growthSwitch;
    }

    public Boolean getEnableGrowthSwitch() {
        return enableGrowthSwitch;
    }

    public void setEnableGrowthSwitch(Boolean enableGrowthSwitch) {
        this.enableGrowthSwitch = enableGrowthSwitch;
    }

    public Boolean getOrganizationSms() {
        return organizationSms;
    }

    public void setOrganizationSms(Boolean organizationSms) {
        this.organizationSms = organizationSms;
    }

    public Boolean getEnableOrganizationSms() {
        return enableOrganizationSms;
    }

    public void setEnableOrganizationSms(Boolean enableOrganizationSms) {
        this.enableOrganizationSms = enableOrganizationSms;
    }

    public Boolean getWxUnbindSwitch() {
        return wxUnbindSwitch;
    }

    public void setWxUnbindSwitch(Boolean wxUnbindSwitch) {
        this.wxUnbindSwitch = wxUnbindSwitch;
    }

    public Boolean getWxElectMembershipCardSwitch() {
        return wxElectMembershipCardSwitch;
    }

    public void setWxElectMembershipCardSwitch(Boolean wxElectMembershipCardSwitch) {
        this.wxElectMembershipCardSwitch = wxElectMembershipCardSwitch;
    }

    public Boolean getAlipayElectMembershipCardSwitch() {
        return alipayElectMembershipCardSwitch;
    }

    public void setAlipayElectMembershipCardSwitch(Boolean alipayElectMembershipCardSwitch) {
        this.alipayElectMembershipCardSwitch = alipayElectMembershipCardSwitch;
    }

    public Integer getManualAutuLabelCount() {
        return manualAutuLabelCount;
    }

    public void setManualAutuLabelCount(Integer manualAutuLabelCount) {
        this.manualAutuLabelCount = manualAutuLabelCount;
    }

    public Integer getDailyAutuLabelCount() {
        return dailyAutuLabelCount;
    }

    public void setDailyAutuLabelCount(Integer dailyAutuLabelCount) {
        this.dailyAutuLabelCount = dailyAutuLabelCount;
    }

    public Integer getMaxStoreType() {
        return maxStoreType;
    }

    public void setMaxStoreType(Integer maxStoreType) {
        this.maxStoreType = maxStoreType;
    }

    public Integer getMaxStoreNum() {
        return maxStoreNum;
    }

    public void setMaxStoreNum(Integer maxStoreNum) {
        this.maxStoreNum = maxStoreNum;
    }

    public Boolean getMbrLogoutSwitch() {
        return mbrLogoutSwitch;
    }

    public void setMbrLogoutSwitch(Boolean mbrLogoutSwitch) {
        this.mbrLogoutSwitch = mbrLogoutSwitch;
    }

    public Integer getMaxAreaType() {
        return maxAreaType;
    }

    public void setMaxAreaType(Integer maxAreaType) {
        this.maxAreaType = maxAreaType;
    }

    public Integer getMaxAreaNum() {
        return maxAreaNum;
    }

    public void setMaxAreaNum(Integer maxAreaNum) {
        this.maxAreaNum = maxAreaNum;
    }
}

==> centercontrol-service-2.0.5-zcc-20220301.012654-1-sources.jar: com/bizvane/centercontrolservice/models/vo/SysBrandConfigVo.java <==
package com.bizvane.centercontrolservice.models.vo;

/**
 * @author pc4
 */
public class SysBrandConfigVo {
    /**
     * 品牌成长值开关
     */
    private Boolean growthSwitch;

    /**
     * 成长值功能启用开关
     */
    private Boolean enableGrowthSwitch;

    /**
     * 品牌组织短信开关
     */
    private Boolean organizationSms;

    /**
     * 品牌组织短信功能启用开关
     */
    private Boolean enableOrganizationSms;


    /**
     * 微信解绑功能开关 0关 1开
     * @return
     */
    private Boolean wxUnbindSwitch;

    /**
     * 会员注销功能开关 0关 1开
     */
    private Boolean mbrLogoutSwitch;


    /**
     * 品牌总部代运营组织运营开关 0关 1开
     */
    private Boolean brandProxyOrgSwitch;

    /**
     * 运营组织独立收款账户开关 0关 1开
     */
    private Boolean organizationWithdrawSwitch;

    /**
     * 运营组织收款账户类型 1品牌总部账户, 2会员所属运营组织账户
     */
    private Integer organizationWithdrawType;

    private Boolean wxElectMembershipCardSwitch;
    private Boolean alipayElectMembershipCardSwitch;

    /**
     * 手动执行自动标签数,默认 5
     * @return
     */
    private Integer manualAutuLabelCount;
    /**
     * 每天执行自动标签数,默认 5
     * @return
     */
    private Integer dailyAutuLabelCount;

    /**
     * 导购助手启用最大店铺数状态 0-不限制 1-限制
     * @return
     */
    private Integer maxStoreType;
    /**
     * 导购助手可启用的最大店铺数 数量0不限制
     * @return
     */
    private Integer maxStoreNum;


    /**
     * 区域通是否开启账号数量限制 0-不开启 1-开启
     */
    private Integer maxAreaType;

    /**
     * 区域通限制账号数量限
     */
    private Integer maxAreaNum;

    /**
     * 会员冻结功能开关 0关 1开
     */
    private Boolean mbrFrozenSwitch;

    public Boolean getMbrFrozenSwitch() {
        return mbrFrozenSwitch;
    }

    public void setMbrFrozenSwitch(Boolean mbrFrozenSwitch) {
        this.mbrFrozenSwitch = mbrFrozenSwitch;
    }

    /**
     * 官方标签同步企微开关0关1开
     */
    private Integer wxqyLabelSyncSwitch;

    public Integer getWxqyLabelSyncSwitch() {
        return wxqyLabelSyncSwitch;
    }

    public void setWxqyLabelSyncSwitch(Integer wxqyLabelSyncSwitch) {
        this.wxqyLabelSyncSwitch = wxqyLabelSyncSwitch;
    }

    public Boolean getGrowthSwitch() {
        return growthSwitch;
    }

    public void setGrowthSwitch(Boolean growthSwitch) {
        this.growthSwitch = growthSwitch;
    }

    public Boolean getEnableGrowthSwitch() {
        return enableGrowthSwitch;
    }

    public void setEnableGrowthSwitch(Boolean enableGrowthSwitch) {
        this.enableGrowthSwitch = enableGrowthSwitch;
    }

    public Boolean getOrganizationSms() {
        return organizationSms;
    }

    public void setOrganizationSms(Boolean organizationSms) {
        this.organizationSms = organizationSms;
    }

    public Boolean getEnableOrganizationSms() {
        return enableOrganizationSms;
    }

    public void setEnableOrganizationSms(Boolean enableOrganizationSms) {
        this.enableOrganizationSms = enableOrganizationSms;
    }

    public Boolean getWxUnbindSwitch() {
        return wxUnbindSwitch;
    }

    public void setWxUnbindSwitch(Boolean wxUnbindSwitch) {
        this.wxUnbindSwitch = wxUnbindSwitch;
    }

    public Boolean getWxElectMembershipCardSwitch() {
        return wxElectMembershipCardSwitch;
    }

    public void setWxElectMembershipCardSwitch(Boolean wxElectMembershipCardSwitch) {
        this.wxElectMembershipCardSwitch = wxElectMembershipCardSwitch;
    }

    public Boolean getAlipayElectMembershipCardSwitch() {
        return alipayElectMembershipCardSwitch;
    }

    public void setAlipayElectMembershipCardSwitch(Boolean alipayElectMembershipCardSwitch) {
        this.alipayElectMembershipCardSwitch = alipayElectMembershipCardSwitch;
    }

    public Integer getManualAutuLabelCount() {
        return manualAutuLabelCount;
    }

    public void setManualAutuLabelCount(Integer manualAutuLabelCount) {
        this.manualAutuLabelCount = manualAutuLabelCount;
    }

    public Integer getDailyAutuLabelCount() {
        return dailyAutuLabelCount;
    }

    public void setDailyAutuLabelCount(Integer dailyAutuLabelCount) {
        this.dailyAutuLabelCount = dailyAutuLabelCount;
    }

    public Integer getMaxStoreType() {
        return maxStoreType;
    }

    public void setMaxStoreType(Integer maxStoreType) {
        this.maxStoreType = maxStoreType;
    }

    public Integer getMaxStoreNum() {
        return maxStoreNum;
    }

    public void setMaxStoreNum(Integer maxStoreNum) {
        this.maxStoreNum = maxStoreNum;
    }

    public Boolean getMbrLogoutSwitch() {
        return mbrLogoutSwitch;
    }

    public void setMbrLogoutSwitch(Boolean mbrLogoutSwitch) {
        this.mbrLogoutSwitch = mbrLogoutSwitch;
    }

    public Integer getMaxAreaType() {
        return maxAreaType;
    }

    public void setMaxAreaType(Integer maxAreaType) {
        this.maxAreaType = maxAreaType;
    }

    public Integer getMaxAreaNum() {
        return maxAreaNum;
    }

    public void setMaxAreaNum(Integer maxAreaNum) {
        this.maxAreaNum = maxAreaNum;
    }

    public Boolean getBrandProxyOrgSwitch() {
        return brandProxyOrgSwitch;
    }

    public void setBrandProxyOrgSwitch(Boolean brandProxyOrgSwitch) {
        this.brandProxyOrgSwitch = brandProxyOrgSwitch;
    }

    public Boolean getOrganizationWithdrawSwitch() {
        return organizationWithdrawSwitch;
    }

    public void setOrganizationWithdrawSwitch(Boolean organizationWithdrawSwitch) {
        this.organizationWithdrawSwitch = organizationWithdrawSwitch;
    }

    public Integer getOrganizationWithdrawType() {
        return organizationWithdrawType;
    }

    public void setOrganizationWithdrawType(Integer organizationWithdrawType) {
        this.organizationWithdrawType = organizationWithdrawType;
    }
}
